@@ -1,7 +1,9 @@
 import pygame
 import math
 
-import palletts as p
+# import palletts as p
+
+import cofffee.palletts as p
 
 
 class text:
